==> spatialpy-1.0-py3-none-any.whl: spatialpy/__version__.py <==
'''
SpatialPy is a Python 3 package for simulation of
spatial deterministic/stochastic reaction-diffusion-advection problems
Copyright (C) 2019 - 2022 SpatialPy developers.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU GENERAL PUBLIC LICENSE Version 3 as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU GENERAL PUBLIC LICENSE Version 3 for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

# =============================================================================
# @file    __version__.py
# @brief   SpatialPy version info
# @license Please see the file named LICENSE in the project directory
# @website https://github.com/StochSS/SpatialPy
# =============================================================================

__version__      = '1.0'
__title__        = 'SpatialPy'
__description__  = 'Python Interface for Spatial Stochastic Biochemical Simulations'
__url__          = 'https://spatialpy.github.io/SpatialPy/'
__download_url__ = 'https://github.com/StochSS/SpatialPy/tarball/main/'
__author__       = 'See AUTHORS'
__email__        = 'bdrawert@unca.edu'
__license__      = 'GPL-3.0-only'
__copyright__    = 'Copyright (C) 2017-2022'

==> spatialpy-1.0.1-py3-none-any.whl: spatialpy/__version__.py <==
'''
SpatialPy is a Python 3 package for simulation of
spatial deterministic/stochastic reaction-diffusion-advection problems
Copyright (C) 2019 - 2022 SpatialPy developers.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU GENERAL PUBLIC LICENSE Version 3 as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU GENERAL PUBLIC LICENSE Version 3 for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

# =============================================================================
# @file    __version__.py
# @brief   SpatialPy version info
# @license Please see the file named LICENSE in the project directory
# @website https://github.com/StochSS/SpatialPy
# =============================================================================

__version__      = '1.0.1'
__title__        = 'SpatialPy'
__description__  = 'Python Interface for Spatial Stochastic Biochemical Simulations'
__url__          = 'https://spatialpy.github.io/SpatialPy/'
__download_url__ = 'https://github.com/StochSS/SpatialPy/tarball/main/'
__author__       = 'See AUTHORS'
__email__        = 'bdrawert@unca.edu'
__license__      = 'GPL-3.0-only'
__copyright__    = 'Copyright (C) 2017-2022'
